<?

/**
 * Draws the top portfolio link(s)
 *
 * $cssClass: The CSS class to use for the link
 * $category: The category (or sub category) that we are rendering this link for
 * $text: The link text
 * $on: The current category that we are on/showing
 * $param: The parameter name for the url (s|sc)
 * $qStr: The page query string to use to replace category bits as needed
 * $img: The image param if the menu item is an image
 */
function drawPortfolioLink ($cssClass, $category, $text, $on, $param, $qStr="", $img="") {

	$str = "";
	$qStr = ($qStr != "") ? "{$qStr}&" : "";
	
	if ($img != "") {
		// this assumes a bit, but that's ok
		$img = ($category == $on) ? str_replace(".", "_on.", $img) : $img;
		$str .= "<a class=\"{$cssClass}\" href=\"{$_SERVER["SCRIPT_NAME"]}?{$qStr}{$param}={$category}\">";
		$str .= "<img src=\"{$img}\" width=\"22\" height=\"20\" alt=\"{$text}\" />";
		$str .= "</a>";
	} else {
		$css = ($category == $on) ? " On" : "";
		$str .= "<a class=\"{$cssClass} {$css}\" href=\"{$_SERVER["SCRIPT_NAME"]}?{$qStr}{$param}={$category}\">{$text}</a>";
	}

	return $str;
}

/**
 * Returns the sub links for a given category
 *
 * PENDING: It's messy to have these in here. Or at least it seems that way. 
 *
 * $c: The category to load sub links for
 */
function getSubMenuLinks ($c) {

	$subCats = array(
		"design" => array(
				"intro" => "Intro",
				"li" => "Logos/Identity",
				"co" => "Collateral",
				"pr" => "Presentation",
				"ts" => "T-shirts",
				"md" => "Miscellaneous"
		),
		"apps" => array(
				"intro" => "Intro",
				"ca" => "Cataphora",
				"dm" => "Digital Mirror",
				"ic" => "Icons",
				"tr" => "Troba"
		),
		"video" => array(
				"intro" => "Intro",
				"cs" => "Cataphora Software",
				"po" => "Pecking Order",
				"as" => "Arab Spring",
				"pe" => "Personal"
		),
		"code" => array(
				"intro" => "Intro",
				"php" => "PHP",
				"port" => "This Portfolio",
				"js" => "JavaScript",
				"java" => "Java"
		)
	);

	return (! isset($subCats[$c])) ? array() : $subCats[$c];
}

/**
 * Renders the carousel of portfolio items
 *
 * $items: The items to render (from the data file)
 * $subCategory: The sub category to filter for
 * $mobile: If mobile or not (the layout is slightly tweaked based on this)
 */
function renderPortfolioItems ($items, $subCategory, $mobile) {

	$str = "";
	$tally = 0;
	$mobileCSS = ($mobile) ? " class=\"mobile\"" : "";
	
	// loooooooooooop
	foreach ($items as $p) {
		$pBits = explode("\t", trim($p));
		$pDispFile = "";
		$url = "";
		
		// are we skipping it?
		if ( (count($pBits) < 2) || ($subCategory != "") && ($pBits[1] != $subCategory) ) {
			continue;
		}
		
		// can we see it?
		if (isset($pBits[6])) {
			$url .= "<b>Note:</b> This is availble to be <a href=\"{$pBits[6]}\" target=\"_blank\">";
			$url .= "viewed online";
			$url .= "</a>.";
		}

		// no shadow?
		$css = ($pBits[5] == "F") ? "class=\"noborder\" " : "";
		// iframe and/ video?
		$iframe = false;
		$video = false;
		// portfolio file and meta text
		switch ($pBits[4]) {
			case "image/jpg":
				$pDispFile = "{$pBits[3]}.jpg";
				break;
			case "image/gif":
				$pDispFile = "{$pBits[3]}.gif";
				break;
			case "image/png":
				$pDispFile = "{$pBits[3]}.png";
				break;
			case "application/pdf":
				$pDispFile = "{$pBits[3]}.pdf";
				$iframe = true;
				break;
			case "text/html":
				$pDispFile = "{$pBits[3]}.html?rand=".rand(111111,999999);
				$iframe = true;
				break;
			case "video/mp4":
				$pDispFile = $pBits[3];
				$video = true;
				$iframe = true;
				break;
		}

		// the year of the item (this works as long as i follow my own naming structure
		preg_match("/_\d{4}\.+/", $pDispFile, $matches);
		$year = str_replace(array("_", "."), "", $matches[0]);

		// the text file - load and prep
		if ($video) {
			// same as year - works as long as i follow my own naming structure
			$params = explode("?", $pBits[3]);
			$eachParam = explode("&", $params[1]);
			$root = str_replace($_SERVER["SCRIPT_NAME"], "", $_SERVER["SCRIPT_FILENAME"]);
			$pTextFile = "{$root}".str_replace(array("v=", ".mp4"), "", $eachParam[0]).".txt";
		} else {
			$pTextFile = "{$pBits[3]}.txt";
		}
		$pItemText = (is_file($pTextFile))
			? implode("", file($pTextFile))
			: "";
		// the slide
		$str .= "<li id=\"pi_{$tally}\">\n";
		$str .= "\t<div class=\"pImg\" id=\"img_{$tally}\">\n";
		if ($iframe) {
				$str .= "<iframe {$css}src=\"{$pDispFile}\"></iframe>";
		} else {
			if (is_file($pDispFile)) {
				$str .= "<a class=\"portImg\" href=\"{$pDispFile}\">";
				$str .= "<img {$css}src=\"{$pDispFile}\" alt=\"portfolio image - please load\" />";
				$str .= "</a>";
			}
		}
		$str .= "</div>\n";
		$str .= "\t<div class=\"pText\">";

		// $str .= "\t\t<h1>{$pBits[2]}</h1>\n";
		// $str .= "\t\t<h2>{$year}</h2>\n";
		$str .= "\t\t<h1>{$year} &#155; {$pBits[2]}</h1>\n";

		$str .= ($mobile)
			? "\t\t".str_replace("<p>", "<p{$mobileCSS}>", $pItemText)."\n"
			: "\t\t{$pItemText}\n";
		$str .= ($url != "") ? "<div class=\"smaller\">{$url}</div>\n" : "";

		$str .= "\t<div class=\"bottomFade\"></div>\n";

		$str .= "\t</div>\n";
		$str .= "</li>\n";
		$tally++;
	}

	return $str;
}

// 
/**
 * Renders the pager links for the portfolio items
 *
 * $items: The items to render paging for (from the data file)
 * $subCategory: The sub category to filter for
 */
function renderPortfolioItemPager ($items, $subCategory) {

	$str = "";
	$tally = 0;
	
	// loooooooooooop
	foreach ($items as $p) {
		$pBits = explode("\t", trim($p));

		// are we skipping it?
		if ( (count($pBits) < 2) || ($subCategory != "") && ($pBits[1] != $subCategory) ) {
			continue;
		}

		$tPlus = ($tally + 1);
		$str .= "<li><a rel=\"{$tally}\" class=\"pagenum\" href=\"#\">{$tPlus}</a></li>\n";
		$tally++;
	}

	return $str;
}

/**
 * Loads the specified intro text
 *
 * $id: The string to look for to load an intro that matches
 * $mobile: If mobile or not (a usability message is added depending on this)
 */
function showIntroText ($id, $mobile) {

	$f = dirname($_SERVER["SCRIPT_FILENAME"])."/_data/intros/{$id}.txt";
	$str = "";

	if (is_file($f)) {
		$str .= implode("", file($f));
		// who loves ya?
		if ($mobile) {
			$str .= "<p><b>Attention mobile user:</b> For your convenience, you can swipe left or right on the description text area on any slide to move back and forth.</p>";
		} else {
			$str .= "<p><b>Attention desktop user:</b> For your convenience, you can use your left and right arrow keys to move back and forth between slides.</p>";
		}

		return $str;
	}
}

/**
 * Nicely formats the size of a file
 *
 * $file: The file (including path) to get the size for
 */
function getFileSize ($file) { 

	$str = "";
	$fSize = filesize($file);
	
	if ((strlen($fSize) <= 9) && (strlen($fSize) >= 7)) {
		$str = number_format($fSize / 1048576, 1)." MB"; 
	} else if (strlen($fSize) >= 10) { 
		$str = number_format($fSize / 1073741824, 1)." GB"; 
	} else { 
		$str = number_format($fSize / 1024, 1)." KB"; 
	} 

	return $str;
} 

/**
 * Just being nosy - ya i could check this in access logs, but
 *	this is cleaner...there shouldn't be a ton of traffic, and
 *	this way i know if somebody i sent a u/p to came in...
 */
function logVisit () {
	if ($_SERVER["PHP_AUTH_USER"] != "glass") {
		// don't need my primary account
		$log = "{$_SERVER["DOCUMENT_ROOT"]}/history/_data/log/access.txt";
		$access = "{$_SERVER["PHP_AUTH_USER"]}\t{$_SERVER["REQUEST_URI"]}\t".date("r")."\n";
		file_put_contents($log, $access, FILE_APPEND);
	}
}

?>
